pub enum HttpServerCommand<Surface> {
Open(HttpServerSetup<Surface>),
Close,
}Expand description
Requests the desired lifecycle state of one bound HTTP server.
Variants
Open(HttpServerSetup<Surface>)
Requests that this setup be the server currently open.
Close
Requests that no server remain open.