pub fn describe_path<'a, Parts>(parts: Parts) -> Stringwhere
Parts: IntoIterator<Item = &'a RoutePath>,Expand description
Describes one absolute path in the spelling every interpretation states it in.
pub fn describe_path<'a, Parts>(parts: Parts) -> Stringwhere
Parts: IntoIterator<Item = &'a RoutePath>,Describes one absolute path in the spelling every interpretation states it in.