write_header_name

Function write_header_name 

pub fn write_header_name(name: &str) -> String
Writes the name an argument states as the name a header states.

The reverse of read_header_name, for anything stating a header name to a reader rather than reading one: a document keying a parameter, or a client sending it.