HeaderOutAlg

Trait HeaderOutAlg 

pub trait HeaderOutAlg {
    type Header<Inner, Name>;
}
Selects the converter used to answer with a header beside a body.

Required Associated Types

type Header<Inner, Name>

The converter writing Name beside the body Inner states.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors