pub trait HttpRouteAlg:
SelectorAlg
+ HttpSelectorAlg<Selector = <Self as SelectorAlg>::Selector>
+ RouteAlg<Selector = <Self as SelectorAlg>::Selector> { }Expand description
Combines the capabilities required to interpret HTTP route composition.
The alias states that HTTP selectors, route composition, and selector composition are witnessed by one interpreter using a single selector representation.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".