PathSyntaxAlg

Trait PathSyntaxAlg 

pub trait PathSyntaxAlg {
    // Required methods
    fn param(&self, name: &str) -> String;
    fn tail(&self, name: &str) -> String;
}
Spells route-path parameters the way one router reads them.

Required Methods

fn param(&self, name: &str) -> String

Returns the spelling of a parameter binding one segment.

fn tail(&self, name: &str) -> String

Returns the spelling of a parameter binding every remaining segment.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors