ResultOutAlg

Trait ResultOutAlg 

pub trait ResultOutAlg {
    type Result<Inner, Error>;
}
Selects the converter used for a handler that can fail.

Required Associated Types

type Result<Inner, Error>

The converter answering with Inner on success and with what Error means otherwise.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors