pub trait HttpApiAlg:
HandlerAlg
+ HttpInputAlg
+ HttpRouteAlg
+ RouteAlg<Endpoint = <Self as HandlerAlg>::Endpoint> { }Expand description
Combines the capabilities required to interpret a typed HTTP API.
The alias states that endpoints built by the handler capability are the endpoints lifted into composed routes.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".